@@ -18,10 +18,7 @@
  * along with this library; if not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifdef HAVE_CONFIG_H
 #include "config.h"
-#endif
-
 #include "gspell-checker-dialog.h"
 #include <glib/gi18n-lib.h>
 #include "gspell-checker.h"
