@@ -17,10 +17,7 @@
  * along with this library; if not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifdef HAVE_CONFIG_H
 #include "config.h"
-#endif
-
 #include "gspell-entry.h"
 #include "gspell-entry-private.h"
 #include "gspell-entry-buffer.h"
